@@ -6,10 +6,10 @@ from prompt_toolkit.completion import WordCompleter
 from figcli.commands.config_context import ConfigContext
 from figcli.commands.types.config import ConfigCommand
 from figcli.data.dao.ssm import SsmDao
-from figcli.input import Input
+from figcli.io.input import Input
 from figcli.svcs.observability.anonymous_usage_tracker import AnonymousUsageTracker
 from figcli.svcs.observability.version_tracker import VersionTracker
-from figcli.utils.output import Output
+from figcli.io.output import Output
 from figcli.utils.utils import *
 
 
