@@ -12,14 +12,17 @@ class Color:
             self.rd = 'red'
             self.yl = 'yellow'
             self.gr = 'green'
+            self.og = 'orange'
 
             self.bl_val = palette.bl
             self.gr_val = palette.gr
             self.rd_val = palette.rd
             self.yl_val = palette.yl
+            self.og_val = palette.og
 
             self.fg_bl = palette.fg_bl
             self.fg_gr = palette.fg_gr
             self.fg_rd = palette.fg_rd
             self.fg_yl = palette.fg_yl
+            self.fg_og = palette.fg_og
             self.rs = fg.rs
