@@ -11,6 +11,7 @@ class AppleTerminal(Term):
     GREEN = (40, 138, 74)
     RED = (191, 29, 42)
     YELLOW = (199, 142, 10)
+    ORANGE = (232, 149, 39)
 
     def get_colors(self) -> Color:
         return Color(
@@ -19,6 +20,7 @@ class AppleTerminal(Term):
                 blue=AppleTerminal.BLUE,
                 green=AppleTerminal.GREEN,
                 red=AppleTerminal.RED,
-                yellow=AppleTerminal.YELLOW
+                yellow=AppleTerminal.YELLOW,
+                orange=AppleTerminal.ORANGE
             )
         )
